@@ -1,7 +1,11 @@
 # -*- perl -*-
 
 package Bundle::Image::Info::XPM;
-$VERSION = '0.01';
+
+use strict;
+use vars qw($VERSION);
+$VERSION = '0.02';
+
 1;
 
 __END__
@@ -12,6 +16,8 @@ Bundle::Image::Info::XPM - XPM (X11 pixmap) support for Image::Info
 
 =head1 SYNOPSIS
 
+=for test_synopsis BEGIN { die "SKIP: shell code\n"; }
+
  perl -MCPAN -e 'install Bundle::Image::Info::XPM'
 
 =head1 CONTENTS
